Package: clevRvis
Type: Package
Title: Visualization Techniques for Clonal Evolution
Version: 1.11.0
Authors@R: 
	person("Sarah", "Sandmann", , "sarah.sandmann@uni-muenster.de", role = c("aut", "cre"),comment=c(ORCID="0000-0002-5011-0641"))
Description: clevRvis provides a set of visualization
        techniques for clonal evolution. These include shark plots, dolphin
	plots and plaice plots. Algorithms for time point interpolation 
	as well as therapy effect estimation are provided. Phylogeny-aware
	color coding is implemented. A shiny-app for generating plots
	interactively is additionally provided.
License: LGPL-3
Encoding: UTF-8
Requires: shiny, ggraph, igraph, ggiraph, cowplot, htmlwidgets, readxl,
        dplyr, readr, purrr, tibble, patchwork, R.utils, shinyWidgets,
        colorspace, shinyhelper, shinycssloaders, ggnewscale,
        shinydashboard, DT, colourpicker, grDevices, methods, utils,
        stats, ggplot2, magrittr, tools
Imports: shiny, ggraph, igraph, ggiraph, cowplot, htmlwidgets, readxl,
        dplyr, readr, purrr, tibble, patchwork, R.utils, shinyWidgets,
        colorspace, shinyhelper, shinycssloaders, ggnewscale,
        shinydashboard, DT, colourpicker, grDevices, methods, utils,
        stats, ggplot2, magrittr, tools
VignetteBuilder: knitr
Suggests: knitr, rmarkdown, BiocStyle
biocViews: Software, ShinyApps, Visualization
BugReports: https://github.com/sandmanns/clevRvis/issues
URL: https://github.com/sandmanns/clevRvis
RoxygenNote: 7.2.1
git_url: https://git.bioconductor.org/packages/clevRvis
git_branch: devel
git_last_commit: 02b71a5
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 20:33:06 UTC; biocbuild
Author: Sarah Sandmann [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5011-0641>)
Maintainer: Sarah Sandmann <sarah.sandmann@uni-muenster.de>
