export(clevRvisShiny)
export(createSeaObject)
export(dolphinPlot)
export(extSharkPlot)
export(plaicePlot)
export(combinedPlot)
export(sharkPlot)
export(exploreTrees)

exportClasses(seaObject)
exportMethods(
    show,
    ytop, "ytop<-",
    ybtm, "ybtm<-",
    xpos, "xpos<-",
    col, "col<-",
    timepoints, "timepoints<-",
    fracTable, "fracTable<-",
    parents, "parents<-",
    nestLevels, "nestLevels<-",
    cloneFamily, "cloneFamily<-",
    cloneLabels, "cloneLabels<-",
    defaultLabels, "defaultLabels<-",
    originTimepoint, "originTimepoint<-"
)


import('shiny',except=c(validate,setProgress,dataTableOutput,renderDataTable,
                        runExample))
import('shinydashboard')
import('patchwork')
import('ggiraph') 
import('shinyWidgets')

importFrom('ggraph', "ggraph", "geom_edge_elbow")
importFrom('igraph',"graph_from_data_frame")
importFrom('cowplot',"plot_grid")
importFrom('htmlwidgets', "saveWidget")
importFrom('readxl', "read_excel")
importFrom('dplyr', "select", "filter", "as_data_frame")
importFrom('magrittr', "%>%")
importFrom('readr', "parse_number", "read_csv")
importFrom('purrr', "detect_index", "pluck")
importFrom('tibble',"add_column", "add_row")
importFrom('R.utils', "insert")
importFrom('colorspace', "rainbow_hcl", "darken")
importFrom('shinyhelper', 'helper', "observe_helpers")
importFrom('shinycssloaders', "withSpinner")
importFrom('ggnewscale', "new_scale")
importFrom('DT', "dataTableOutput", "datatable", "renderDataTable")
importFrom('colourpicker', "colourInput")
importFrom("grDevices", "colorRampPalette", "col2rgb")
importFrom("methods", "new", "representation", "setMethod", "setGeneric", 
            "is", "setClass", "show")
importFrom("stats", "spline")
importFrom("tools", "file_ext")
importFrom("utils", "tail")
importFrom("ggplot2", "geom_point", "aes", "scale_y_reverse", 
            "scale_x_reverse", "coord_flip")
importFrom("ggplot2", "ggplot", "scale_fill_manual", "theme", "geom_segment", 
            "geom_text", "geom_point")
importFrom("ggplot2", "expand_limits", "guides", "scale_color_discrete", 
            "scale_color_manual", "scale_size_area")
importFrom("ggplot2", "theme_void", "guide_legend", "geom_hline", 
            "scale_colour_manual", ".data")
